#version 330 core
out vec4 FragColor;

in vec2 TexCoords;

uniform sampler2D scene;
uniform sampler2D bloomBlur;
uniform float exposure;

uniform bool bloom_enabled;

/// code below is from https://learnopengl.com/Advanced-Lighting/Bloom
void main() {
  const float gamma = 2.2;
  const float bloom_intensity = 0.2; // the higher the value, the more intense the bloom
  vec3 hdrColor = texture(scene, TexCoords).rgb;
  
  if (bloom_enabled) {
    vec3 bloomColor = texture(bloomBlur, TexCoords).rgb;
    hdrColor += bloomColor * bloom_intensity;
  }

  vec3 result = vec3(1.0) - exp(-hdrColor * exposure); // exposure
  vec3 mapped = hdrColor / (hdrColor + vec3(1.0)); // reinhard tone mapping
  result = pow(mapped, vec3(1.0 / gamma)); // gamma correction
  FragColor = vec4(result, 1.0);
}
