#version 330 core
out vec4 FragColor;

in vec2 TexCoords;

uniform sampler2D image;
uniform bool bloom_enabled;

/// code below is from https://learnopengl.com/Advanced-Lighting/Bloom

uniform bool horizontal;
uniform float weight[5] = float[](0.2270270270, 0.1945945946, 0.1216216216,
                                  0.0540540541, 0.0162162162);

void main() {
  vec2 tex_offset = 1.0 / textureSize(image, 0);  // gets size of single texel
  vec3 result = texture(image, TexCoords).rgb;

  if (!bloom_enabled) {
    FragColor = vec4(result, 1.0);
  } else {
    result = result * weight[0];
    if (horizontal) {
      for (int i = 1; i < 5; ++i) {
        result += texture(image, TexCoords + vec2(tex_offset.x * i, 0.0)).rgb *
                  weight[i];
        result += texture(image, TexCoords - vec2(tex_offset.x * i, 0.0)).rgb *
                  weight[i];
      }
    } else {
      for (int i = 1; i < 5; ++i) {
        result += texture(image, TexCoords + vec2(0.0, tex_offset.y * i)).rgb *
                  weight[i];
        result += texture(image, TexCoords - vec2(0.0, tex_offset.y * i)).rgb *
                  weight[i];
      }
    }

    FragColor = vec4(result, 1.0);
  }
}

